import { NgModule, Component, Input, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';

@Component({
    selector: 'glx-attachments-viewer',
    styleUrls: ['attachmentsViewer.scss'],
    templateUrl: 'attachmentsViewer.html'
})

export class AttachmentsViewer implements OnInit {
    @Input() loading: boolean = false;
    @Input() attachments: any = [];
    @Input() service: any;

    @Input() title: string = 'Прикрепленные файлы';
    @Input() theme: string = 'default';

    @Input() showHr: boolean = true;
    @Input() showName: boolean = true;
    @Input() showThumbnail: boolean = true;

    @Input() imgSize: number = 64;

    constructor() {
    }

    ngOnInit() {
        this.loading = false;
    }

    getFileExtension(name: string): string {
        return '.' + name.split('.').pop();
    }

    getFile(file) {
        if (this.service) {
            this.service.download(file.id)
                .subscribe(
                    () => {
                        // window.open(result, '_blank');
                    },
                    error => {
                        console.error(error);
                    });
        } else {
            console.error('Не указан сервис для отдачи файлов с методом download(id)');
        }

    }

    ifImage(file) {
        return !!(file.thumbnail && file.thumbnai.length > 0);
    }

    getIcon(extension: string) {
        switch (extension.toLowerCase()) {
            case '.jpg':
            case '.png':
            case '.bmp':
            case '.jpeg':
            case '.jif':
            case '.jfif':
            case '.svg':
            case '.psd':
            case '.ai':
            case '.tiff':
            case '.tif':
            case '.gif':
                return 'fa-file-image-o';
            case '.zip':
            case '.rar':
            case '.7z':
            case '.gz':
            case '.jar':
                return 'fa-file-archive-o';
            case '.pdf':
                return 'fa-file-pdf-o';
            case '.xls':
            case '.xlsx':
            case '.csv':
            case '.dbf':
            case '.ods':
                return 'fa-file-excel-o';
            case '.doc':
            case '.docx':
            case '.odt':
                return 'fa-file-word-o';
            case '.ppt':
            case '.pptx':
            case '.odp':
                return 'fa-file-powerpoint-o';
            case '.txt':
                return 'fa-file-text-o';
            case '.avi':
            case '.3gp':
            case '.mkv':
            case '.mp4':
            case '.flv':
            case '.ogv':
            case '.wmv':
            case '.mpg':
            case '.mpeg':
                return 'fa-file-video-o';
            case '.mp3':
            case '.wav':
            case '.aiff':
            case '.aac':
            case '.flac':
            case '.ogg':
            case '.wma':
                return 'fa-file-audio-o';
            case '.xml':
            case '.xsd':
            case '.json':
            case '.html':
            case '.htm':
            case '.js':
            case '.ts':
            case '.css':
            case '.php':
            case '.c':
            case '.cpp':
            case '.h':
            case '.py':
            case '.java':
            case '.class':
            case '.cmd':
            case '.bat':
            case '.sh':
            case '.asp':
            case '.db':
            case '.def':
            case '.ini':
            case '.conf':
            case '.dll':
                return 'fa-file-code-o';
            default:
                return 'fa-file-text-o';
        }
    }
}

@NgModule({
    imports: [CommonModule],
    exports: [AttachmentsViewer],
    declarations: [AttachmentsViewer]
})

export class AttachmentsViewerModule {
}
