import { Component, EventEmitter, Input, NgModule, OnInit, Output } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { GlxSharedModule } from '../kernel/shared.module';
import { TooltipModule } from 'primeng/components/tooltip/tooltip';

/**
 * Поиск сотрудников с детальным просмотром профиля
 */
@Component({
    selector: 'glx-attestations-group',
    styleUrls: ['./attestationsGroup.scss'],
    templateUrl: './attestationsGroup.html'
})

export class AttestationsGroup implements OnInit {
    /**
     * Данные для отображения в таблице
     */
    @Input() data: any = {};
    /**
     * Событий просмотра профиля. Необходимо получить профиль пользователя с сервера
     * @type {EventEmitter<any>}
     */
    @Output() onViewProfile: EventEmitter<any> = new EventEmitter();
    @Output() onViewAttestation: EventEmitter<any> = new EventEmitter();
    @Output() onDownloadExcel: EventEmitter<any> = new EventEmitter();

    /**
     * Конструктор
     * @param {Router} router
     * @param {ActivatedRoute} route
     * @param {Renderer2} renderer
     */
    constructor() {
    }

    /**
     * Проверка префильтров
     */
    ngOnInit() {

    }

    getMonth(month) {
        const months = ['', 'I', 'II', 'III', 'IV', 'V', 'VI', 'VII', 'VIII', 'IX', 'X', 'XI', 'XII'];
        return months[month];
    }

    getMonthName(month) {
        const months = ['', 'Январь', 'Февраль', 'Март', 'Апрель', 'Май', 'Июнь', 'Июль', 'Август', 'Сентябрь', 'Октябрь', 'Ноябрь', 'Декабрь'];
        return months[month];
    }

    getTooltip(item, disc, month) {
        if (month.fake) {
            return 'Дисциплина не читается';
        }
        let result = '<span class="text-muted">Нет информации об аттестации</span>';
        if (month.result === 1) {
            result = '<span class="text-success">Аттестован</span>';
        }
        if (month.result === 0) {
            result = '<span class="text-danger">Неаттестован</span>';
        }

        return `
        <div><b>` + this.getMonthName(month.month) + ` ` + (month.year || '') + `</b></div>
        <div><i>` + disc.title + ` (` + (month.lecturer || '-') + `)</i></div>
        <div>` + item.fullname + ` <span>[` + item.book_num + `]</span></div>
        <div>` + result + `</div>
        `;
    }


    /**
     * Собатие показа профиля в слайдере
     * @param id
     */
    showProfile($event, id) {
        this.onViewProfile.emit(id);
        $event.stopPropagation();
    }

    /**
     * Одиночный щелчок по строке устанавливает ID профиля для возможного открытия
     * @param event
     */
    onRowClick(event) {
        this.onViewAttestation.emit(event);
    }

    exportData(event) {
        this.onDownloadExcel.emit(event);
    }
}

@NgModule({
    imports: [
        CommonModule,
        FormsModule,
        GlxSharedModule,
        TooltipModule
    ],
    exports: [AttestationsGroup],
    declarations: [AttestationsGroup]
})

export class AttestationsGroupModule {
}
