import { NgModule, Component, Input, OnInit, AfterViewInit, ViewChild, ElementRef } from '@angular/core';
import { CommonModule } from '@angular/common';

import { DefaultOptions } from './defaultOptions';

declare let $: any;

@Component({
    selector: 'glx-bup-viewer',
    styleUrls: ['./bupViewer.scss'],
    templateUrl: './bupViewer.html'
})

export class BupViewer implements OnInit, AfterViewInit {
    @Input() data: any;
    @Input() options: any = DefaultOptions;

    _columns: any = [];

    @ViewChild('table') table: ElementRef;

    constructor() {
    }

    ngOnInit() {
        this.initColumns();
    }

    initColumns() {
        // формируем массив колонок, которые нужно показывать
        for (let i = 0; i < this.options.columns.length; i++) {
            if (this.options.columns[i].show &&
                (this.options.columns[i].show === 1 || this.options.columns[i].show === true)) {
                this._columns.push(this.options.columns[i]);
            }
        }
        // сортируем массив колонок
        this._columns.sort(function (a, b) {
            return (a.sort > b.sort) ? 1 : ((b.sort > a.sort) ? -1 : 0);
        });
    }

    ngAfterViewInit() {
        if (this.table && this.table.nativeElement) {
            let level;
            const tableRows = this.table.nativeElement.rows;
            for (let i = 1; i < tableRows.length; i++) {
                $(tableRows[i]).hover(
                    function () {
                        level = tableRows[i].getAttribute('level');
                        for (let ii = i + 1; ii < tableRows.length; ii++) {
                            if (tableRows[ii].getAttribute('level') > level) {
                                $(tableRows[ii]).addClass('hover');
                            } else {
                                break;
                            }
                        }
                    },
                    function () {
                        for (let ii = 0; ii < tableRows.length; ii++) {
                            $(tableRows[ii]).removeClass('hover');
                        }
                    }
                );
            }
        }
    }

    getOffset(offset) {
        const base = 16;
        const padding = 24;
        if (!offset || offset === 0 || offset === '' || offset === '0') {
            return base;
        }

        return offset * padding + base;
    }

    formatSemester(text) {
        return text.split(',').join(', ');
    }

    getControlTypes(item) {
        let exam = 0;
        let test = 0;

        if (item.exam || item.test) {
            exam = +item.exam;
            test = +item.test;
        } else {
            return '';
        }

        let examNum = '';
        let testNum = '';
        let result = '';

        if (exam > 1) {
            examNum = ' [' + exam + ']';
        }
        if (test > 1) {
            testNum = ' [' + test + ']';
        }

        if (exam > 0) {
            result = 'Экзамен' + examNum + ', ';
        }
        if (test > 0) {
            result += 'Зачет' + testNum + ', ';
        }
        return result.slice(0, result.length - 2);
    }
}

@NgModule({
    imports: [CommonModule],
    exports: [BupViewer],
    declarations: [BupViewer]
})

export class BupViewerModule {
}
