import { NgModule, Component, Input, OnInit, Output, EventEmitter } from '@angular/core';
import { CommonModule, DatePipe } from '@angular/common';
import { DataTableModule } from 'primeng/components/datatable/datatable';
import { ContractDetailModule } from '../contractDetail';
import { SliderModule } from '../slider';
import { LoadingBannerModule } from '../loadingBanner';

import { LANG_RU } from './lang_ru';

@Component({
    selector: 'glx-contracts-simple-viewer',
    styleUrls: ['./contractsSimpleViewer.scss'],
    templateUrl: './contractsSimpleViewer.html'
})

export class ContractsSimpleViewer implements OnInit {
    @Input() data: any[];
    @Input() options: any;
    @Input() multiple: boolean = true;
    @Input() lang: any = LANG_RU;
    @Input() noDataMessage: string = 'Нет информации';

    @Input() contract: any;
    @Input() contractHeader: string;
    @Output() onViewContract: EventEmitter<any> = new EventEmitter();
    @Output() onPayment: EventEmitter<any> = new EventEmitter();
    showSide: boolean = false;  // показать договор

    constructor(private datePipe: DatePipe) {
    }

    ngOnInit() {
    }

    paymentHandler(data) {
        this.onPayment.emit(data);
    }

    open(item) {
        const date = this.datePipe.transform(item.date, 'dd.MM.yy') || item.date;
        this.contractHeader = 'Договор ' + item.number + ' от ' + date;
        this.onViewContract.emit(item);
        this.showSide = true;
    }
}

@NgModule({
    imports: [CommonModule, DataTableModule, SliderModule, ContractDetailModule, LoadingBannerModule],
    exports: [ContractsSimpleViewer],
    declarations: [ContractsSimpleViewer],
    providers: [DatePipe]
})

export class ContractsSimpleViewerModule {
}
