import { AfterViewInit, Component, ElementRef, EventEmitter, Input, NgModule, Output, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Russian } from 'flatpickr/dist/l10n/ru';

@Component({
    selector: 'glx-date-picker',
    styleUrls: ['datePicker.scss'],
    templateUrl: 'datePicker.html'
})
export class DatePicker implements AfterViewInit {

    @ViewChild('input') el: ElementRef;

    _value: string;

    @Input()
    get value() {
        return this._value;
    }

    set value(val) {
        this._value = val;
        this.valueChange.emit(this._value);
    }

    @Input() placeholder: string = 'дд.мм.гггг';
    @Input() format: string = 'Y-m-d';
    @Input() altFormat: string = 'd.m.Y';
    @Input() classes: string = '';
    @Input() icon: string = 'fa-calendar';
    @Input() iconClear: string = 'fa-trash-o';
    @Input() disabled: boolean = false;
    @Input() allowInput: boolean = false;
    @Input() required: boolean = false;
    @Input() weekNumbers: boolean = false;
    @Input() allowClear: boolean = true;
    @Input() defaultDate: string;
    @Input() maxDate: string;
    @Input() minDate: string;

    @Output() valueChange = new EventEmitter<string>();

    config: any = {
        locale: Russian,
        dateFormat: 'Y-m-d',
        altInput: true,
        altFormat: 'd.m.Y',
        wrap: true,
        allowInput: false,
        defaultDate: null,
        maxDate: null,
        minDate: null,
        time_24hr: true,
        weekNumbers: false,
    };

    constructor() {
    }

    ngAfterViewInit() {
        this.config.dateFormat = this.format;
        this.config.altFormat = this.altFormat;
        this.config.allowInput = this.allowInput;
        this.config.weekNumbers = this.weekNumbers;
        this.config.defaultDate = this.defaultDate ? this.defaultDate : null;
        this.config.maxDate = this.maxDate ? this.maxDate : null;
        this.config.minDate = this.minDate ? this.minDate : null;

        this.el.nativeElement.flatpickr(this.config);
        if (this.disabled) {
            this.el.nativeElement.flatpickr(this.config)._input.setAttribute('disabled', 'disabled');
        }
    }
}

@NgModule({
    imports: [CommonModule, FormsModule],
    exports: [DatePicker],
    declarations: [DatePicker]
})

export class DatePickerModule {
}
