import { Injectable } from '@angular/core';
import { Http, Response } from '@angular/http';
import { AuthHttp } from 'angular2-jwt';

import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';

@Injectable()
export class CatalogService {

    private apiUrl: string = '/api/catalogs/';

    constructor(private authHttp: AuthHttp, private http: Http) {
    }

    public setUrl(url: string) {
        this.apiUrl = url;
    }

    public get(id: number | string, secure: boolean): Observable<any> {
        if (secure) {
            return this.authHttp
                .get(this.apiUrl + id)
                .map((response: Response) => {
                    return response.json();
                })
                .catch(this._handleError);
        } else {
            return this.http
                .get(this.apiUrl + id)
                .map((response: Response) => {
                    return response.json();
                })
                .catch(this._handleError);
        }
    }

    private _handleError(error: any) {
        console.error(error);
        if (error instanceof Response) {
            return Observable.throw(error.json().error || error.json() || 'Server error');
        }
        return Observable.throw(error || 'Server error');
    }

}
