import { Injectable } from '@angular/core';
import { Http, Response } from '@angular/http';
import { Observable } from 'rxjs/Observable';
import { AuthHttp } from 'angular2-jwt';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';
import 'rxjs/add/operator/publishReplay';

@Injectable()
export class SettingsService {

    private apiUrl: string = '/bitrix/vuz/api/settings/';
    private _valueCache: any = {};
    private _sectionCache: any = {};
    private _cacheDate: any = {};

    private secure: boolean = false;
    private http: any;

    constructor(private commonHttp: Http, private authHttp: AuthHttp) {
        this.http = this.commonHttp;
    }

    public setUrl(url: string) {
        this.apiUrl = url;
    }

    public useAuth(b: boolean) {
        this.secure = b;
        if (this.secure) {
            this.http = this.authHttp;
        } else {
            this.http = this.commonHttp;
        }
    }

    clearCache(key?: string) {
        if (key) {
            if (this._valueCache.hasOwnProperty(key)) {
                delete this._valueCache[key];
                delete this._cacheDate[key];
            }
            if (this._sectionCache.hasOwnProperty(key)) {
                delete this._sectionCache[key];
                delete this._cacheDate[key];
            }
        } else {
            this._valueCache = {};
            this._sectionCache = {};
            this._cacheDate = {};
        }
    }


    public get(name: string): Observable<any> {
        if (!this._valueCache.hasOwnProperty(name)) {
            const url = this.apiUrl + 'value/' + name;
            this._cacheDate[name] = new Date();

            this._valueCache[name] = this.http
                .get(url)
                .map((response: Response) => {
                    return response.json();
                })
                .publishReplay(1)
                .refCount()
                .catch(this._handleError);
        }
        return this._valueCache[name];
    }

    public getSection(section: string): Observable<any> {
        if (!this._sectionCache.hasOwnProperty(section)) {
            const url = this.apiUrl + 'section/' + section;
            this._cacheDate[section] = new Date();

            this._sectionCache[section] = this.http
                .get(url)
                .map((response: Response) => {
                    return response.json();
                })
                .publishReplay(1)
                .refCount()
                .catch(this._handleError);
        }
        return this._sectionCache[section];
    }

    private _handleError(error: any) {
        console.error(error);
        if (error instanceof Response) {
            return Observable.throw(error.json().error || error.json() || 'Server error');
        }
        return Observable.throw(error || 'Server error');
    }
}
