import { NgModule, Component, EventEmitter, Input, OnInit, Output, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';
import { DialogModule } from 'primeng/components/dialog/dialog';
import { ImageCropperComponent, CropperSettings, ImageCropperModule } from 'ng2-img-cropper';

@Component({
    selector: 'glx-photo-input',
    styleUrls: ['photoInput.scss'],
    templateUrl: 'photoInput.html'
})

export class PhotoInput implements OnInit {
    data: any;
    cropperSettings: CropperSettings;
    filesize: string;
    originalImage: string;
    display: boolean = false;
    showDeleteButton: boolean = true;

    @Input() showAddButton: boolean = true;
    @Input() filename: string;
    @Input() image: string = '';
    @Input() defaultImage: string = '';

    @ViewChild('cropper') cropper: ImageCropperComponent;

    @Output() onChange: EventEmitter<any> = new EventEmitter();

    showDialog() {
        this.display = true;
    }

    constructor() {
    }

    ngOnInit() {
        this.originalImage = this.image;
        this.cropperSettings = new CropperSettings();
        this.cropperSettings.noFileInput = true;
        this.cropperSettings.width = 400;
        this.cropperSettings.height = 400;
        this.cropperSettings.croppedWidth = 400;
        this.cropperSettings.croppedHeight = 400;
        this.cropperSettings.canvasWidth = 400;
        this.cropperSettings.canvasHeight = 300;
        this.cropperSettings.fileType = 'image/jpeg';
        this.data = {};
    }

    onCrop(event) {
        this.onChange.emit({originalEvent: event, image: this.data.image});
    }

    cancel() {
        this.display = false;
        this.data = {};
        this.image = this.originalImage;
        this.onChange.emit({image: ''});
    }

    save() {
        this.display = false;
        this.image = this.data.image || this.originalImage;
        this.onChange.emit({image: this.image});
    }

    deleteImage() {
        this.data = {};
        this.image = '';
        this.originalImage = '';
        this.onChange.emit({image: 'deleted'});
    }

    fileChangeListener($event) {
        if ($event.target.files.length === 0) {
            return;
        }
        const image: any = new Image();
        const file: File = $event.target.files[0];
        const myReader: FileReader = new FileReader();
        const that = this;

        myReader.onloadend = function (loadEvent: any) {
            image.src = loadEvent.target.result;
            image.addEventListener('load', () => {
                that.cropper.setImage(image);
            });
        };

        myReader.readAsDataURL(file);

        this.filename = file.name;
        this.filesize = this.formatSize(file.size);
    }

    formatSize(bytes) {
        if (bytes === 0) {
            return '0 байт';
        }
        const k = 1000,
            dm = 3,
            sizes = ['байт', 'Кб', 'Мб', 'Гб', 'Тб', 'Пб', 'Эб', 'Зб', 'Йб'],
            i = Math.floor(Math.log(bytes) / Math.log(k));

        return Math.round(parseFloat((bytes / Math.pow(k, i)).toFixed(dm))) + '&nbsp;' + sizes[i];
    }
}


@NgModule({
    imports: [CommonModule, DialogModule, ImageCropperModule],
    exports: [PhotoInput],
    declarations: [PhotoInput]
})
export class PhotoInputModule {
}
