import { Component, EventEmitter, Input, NgModule, OnInit, Output, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { TreeComponent, TreeModule } from 'angular-tree-component';

import { GlxSharedModule } from '../kernel/shared.module';
import { LoadingBannerModule } from '../loadingBanner/loadingBanner';

import { DefaultOptions } from './defaultOptions';

@Component({
    selector: 'glx-structure-viewer',
    styleUrls: ['./structureViewer.scss'],
    templateUrl: './structureViewer.html'
})

export class StructureViewer implements OnInit {
    @Input() structure: any[];
    @Input() options: any = DefaultOptions;

    treeOptions: any = {};
    @ViewChild('tree') gTree: TreeComponent;

    @Output() onSelect: EventEmitter<any> = new EventEmitter();

    constructor() {
    }

    ngOnInit() {
        this.initTree();
    }

    private initTree() {
        this.treeOptions = {
            allowDrag: false,
            allowDrop: false
        };
    }

    open(node) {
        this.onSelect.emit({id: node.id, name: node.name, node: node});
    }
}

@NgModule({
    imports: [CommonModule, GlxSharedModule, FormsModule, TreeModule, LoadingBannerModule],
    exports: [StructureViewer],
    declarations: [StructureViewer]
})

export class StructureViewerModule {
}
