import { Component, EventEmitter, Input, NgModule, OnInit, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { User } from '../kernel/models/user.model';
import { GlxSharedModule } from '../kernel/shared.module';
import { TooltipModule } from 'primeng/components/tooltip/tooltip';
import { DefaultOptions } from './defaultOptions';
import { Router } from '@angular/router';

@Component({
    selector: 'glx-user-viewer',
    styleUrls: ['./userViewer.scss'],
    templateUrl: './userViewer.html'
})

export class UserViewer implements OnInit {
    @Input() user: User;
    @Input() options: any = DefaultOptions;
    @Input() myProfile: boolean = false;
    @Input() slider: boolean = false;

    @Output() onEdit: EventEmitter<any> = new EventEmitter();
    @Output() onChat: EventEmitter<any> = new EventEmitter();
    @Output() onProfileView: EventEmitter<any> = new EventEmitter();
    @Output() onManagerView: EventEmitter<any> = new EventEmitter();
    @Output() onSearchFilter: EventEmitter<any> = new EventEmitter();
    @Output() showMonitoringAction: EventEmitter<any> = new EventEmitter();

    _photo: string;
    _info: any;
    _rank: any;
    _degree: any;
    _personal: any;
    _extra: any;

    constructor(private router: Router) {
    }

    ngOnInit() {
        this.setPhoto();
        this.setDegree();
        this.setRank();
        this.setPersonal();
        this.setExtra();
        this.setInfo();
    }

    /**
     * НЕ показывать в чужом профиле
     * @returns {boolean}
     */
    isMyProfile() {
        return this.myProfile;
    }

    private setPhoto() {
        let photo = '';
        if (this.user && this.user.photo && this.user.photo.length > 0) {
            if (this.options && this.options.imagePrefix && this.options.imagePrefix.length > 0) {
                photo = this.options.imagePrefix + this.user.photo;
            } else {
                photo = this.user.photo;
            }
        } else {
            if (this.options && this.options.defaultImage && this.options.defaultImage.length > 0) {
                photo = this.options.defaultImage;
            }
        }
        this._photo = photo;
    }

    private setDegree() {
        if (this.user.profiles && this.user.profiles.length > 0) {
            for (let i = 0; i < this.user.profiles.length; i++) {
                const profile = this.user.profiles[i];
                if (profile.degree && profile.degree.length > 0) {
                    this._degree = profile.degree;
                    return true;
                }
            }
        }
        return false;
    }

    private setRank() {
        if (this.user.profiles && this.user.profiles.length > 0) {
            for (let i = 0; i < this.user.profiles.length; i++) {
                const profile = this.user.profiles[i];
                if (profile.rank && profile.rank.length > 0) {
                    this._rank = profile.rank;
                    return true;
                }
            }
        }
        return false;
    }

    private setPersonal() {
        const personal: any = {};
        if (this.user && this.user.bitrix_login && this.user.bitrix_login.length > 0) {
            personal.login = this.user.bitrix_login;
        }
        if (this.user && this.user.bitrix_email && this.user.bitrix_email.length > 0) {
            personal.email_notify = this.user.bitrix_email;
        }
        this._personal = personal;
    }

    private setExtra() {
        const extra: any = {};
        if (this.user && this.user.last_activity_date && this.user.last_activity_date.length > 0) {
            extra.last_activity_date = this.user.last_activity_date;
        }
        if (this.user && this.user.address && this.user.address.length > 0) {
            extra.address = this.user.address;
        }
        this._extra = extra;
    }

    private setInfo() {
        const info = {
            main: {},
            extra: [],
            student: []
        };
        if (this.user && this.user.profiles && this.user.profiles.length > 0) {
            for (let i = 0; i < this.user.profiles.length; i++) {
                const profile = this.user.profiles[i];
                if (profile.role === 'employee') {
                    if (profile.department) {
                        profile.deps = this.setDeps(profile.department);
                    }
                    if (profile.job_type === 'Основное' || profile.job_type === 'main') {
                        if (!this.isEmpty(info.main)) {
                            console.error('Обнаружено два основных места работы');
                        }
                        if (profile.address && profile.address.length > 0) {
                            this._extra.address = profile.address;
                        }
                        if (profile.work_address && profile.work_address.length > 0) {
                            this._extra.address = profile.work_address;
                        }
                        if (profile.web && profile.web.length > 0) {
                            this._extra.web = profile.web;
                        }
                        if (this.user.email && this.user.email.length > 0 && (this.isMyProfile() ||
                                (profile.show_email && profile.show_email === '1'))) {
                            this._extra.email = this.user.email;
                        }
                        if (this.user.birthdate && this.user.birthdate.length > 0 && (this.isMyProfile() ||
                                (profile.show_birthdate && profile.show_birthdate === '1'))) {
                            this._personal.birthdate = this.user.birthdate;
                        }
                        if (profile.mobile && profile.mobile.length > 0 && (this.isMyProfile() ||
                                (profile.show_mobile && profile.show_mobile === '1'))) {
                            this._extra.mobile = profile.mobile;
                        }
                        if (profile.prof_notes && profile.prof_notes.length > 0) {
                            this._extra.prof_notes = profile.prof_notes;
                        }
                        if (profile.notes && profile.notes.length > 0) {
                            this._extra.notes = profile.notes;
                        }

                        info.main = profile;
                    } else {
                        if (!this._personal.birthdate || this._personal.birthdate.length === 0) {
                            if (this.user.birthdate && this.user.birthdate.length > 0 &&
                                (this.isMyProfile() || (profile.show_birthdate && profile.show_birthdate === '1'))) {
                                this._personal.birthdate = this.user.birthdate;
                            }
                        }
                        if ((!this._extra.address || this._extra.address.length === 0) &&
                            profile.address && profile.address.length > 0) {
                            this._extra.address = profile.address;
                        }
                        if ((!this._extra.address || this._extra.address.length === 0) &&
                            profile.work_address && profile.work_address.length > 0) {
                            this._extra.address = profile.work_address;
                        }
                        if ((!this._extra.web || this._extra.web.length === 0) && profile.web && profile.web.length > 0) {
                            this._extra.web = profile.web;
                        }
                        if ((!this._extra.email || this._extra.email.length === 0) && this.user.email &&
                            this.user.email.length > 0 && (this.isMyProfile() || (profile.show_email && profile.show_email === '1'))) {
                            this._extra.email = this.user.email;
                        }
                        if ((!this._extra.mobile || this._extra.mobile.length === 0) && profile.mobile &&
                            profile.mobile.length > 0 && (this.isMyProfile() || (profile.show_mobile && profile.show_mobile === '1'))) {
                            this._extra.mobile = profile.mobile;
                        }
                        if ((!this._extra.prof_notes || this._extra.prof_notes.length === 0) &&
                            profile.prof_notes && profile.prof_notes.length > 0) {
                            this._extra.prof_notes = profile.prof_notes;
                        }
                        if ((!this._extra.notes || this._extra.notes.length === 0) && profile.notes && profile.notes.length > 0) {
                            this._extra.notes = profile.notes;
                        }

                        info.extra.push(profile);
                    }
                }
                if (profile.role === 'student') {
                    switch (profile.type) {
                        case 'aspirant':
                            profile.type_name = 'Аспирант';
                            break;
                        case 'student':
                            profile.type_name = 'Студент';
                            break;
                        default:
                            profile.type_name = 'Студент';
                    }
                    if (!this._personal.birthdate || this._personal.birthdate.length === 0) {
                        if (this.user.birthdate && this.user.birthdate.length > 0 &&
                            (this.isMyProfile() || (profile.show_birthdate && profile.show_birthdate === '1'))) {
                            this._personal.birthdate = this.user.birthdate;
                        }
                    }
                    if ((!this._extra.address || this._extra.address.length === 0) &&
                        profile.address && profile.address.length > 0) {
                        this._extra.address = profile.address;
                    }
                    if ((!this._extra.address || this._extra.address.length === 0) &&
                        profile.work_address && profile.work_address.length > 0) {
                        this._extra.address = profile.work_address;
                    }
                    if ((!this._extra.web || this._extra.web.length === 0) &&
                        profile.web && profile.web.length > 0) {
                        this._extra.web = profile.web;
                    }
                    if ((!this._extra.email || this._extra.email.length === 0) &&
                        this.user.email && this.user.email.length > 0 &&
                        (this.isMyProfile() || (profile.show_email && profile.show_email === '1'))) {
                        this._extra.email = this.user.email;
                    }
                    if ((!this._extra.mobile || this._extra.mobile.length === 0) &&
                        profile.mobile && profile.mobile.length > 0 &&
                        (this.isMyProfile() || (profile.show_mobile && profile.show_mobile === '1'))) {
                        this._extra.mobile = profile.mobile;
                    }
                    if ((!this._extra.prof_notes || this._extra.prof_notes.length === 0) &&
                        profile.prof_notes && profile.prof_notes.length > 0) {
                        this._extra.prof_notes = profile.prof_notes;
                    }
                    if ((!this._extra.notes || this._extra.notes.length === 0) &&
                        profile.notes && profile.notes.length > 0) {
                        this._extra.notes = profile.notes;
                    }

                    info.student.push(profile);
                }
            }
        }
        this._info = info;
    }

    private setDeps(departments) {
        const deps = [];
        if (departments && departments.child && departments.child.id) {
            let dep = departments;
            deps.push(dep);
            while (dep.child) {
                dep = dep.child;
                if (dep.id) {
                    deps.push(dep);
                }
            }
        } else {
            if (departments && departments.id) {
                deps.push(departments);
            }
        }
        return deps;
    }

    openDialog() {
        this.onChat.emit({bitrix_id: this.user.bitrix_id});
    }

    edit() {
        this.onEdit.emit({id: this.user.id});
    }

    filterSearch(field, value, type) {
        this.onSearchFilter.emit({field: field, value: value, type: type});
    }

    showProfile(id) {
        this.onProfileView.emit({id: id});
    }

    showManager(id) {
        this.onManagerView.emit({id: id});
    }

    showMonitoring() {
        if (this.myProfile) {
            this.router.navigate(['mon', 'aments']);
        } else {
            this.router.navigate(['mon', 'public', this.user.profiles[0].id, new Date().getFullYear(), -1, 'view']);
        }
        //this.showMonitoringAction.emit();
    }

    getDescription(text) {
        if (text && text.length > 0) {
            return text.replace(/\r?\n/g, '<br/>');
        }
        return text;
    }

    isEmpty(obj) {

        // null and undefined are "empty"
        if (obj == null) {
            return true;
        }

        // Assume if it has a length property with a non-zero value
        // that that property is correct.
        if (obj.length > 0) {
            return false;
        }
        if (obj.length === 0) {
            return true;
        }

        // If it isn't an object at this point
        // it is empty, but it can't be anything *but* empty
        // Is it empty?  Depends on your application.
        if (typeof obj !== 'object') {
            return true;
        }

        // Otherwise, does it have any properties of its own?
        // Note that this doesn't handle
        // toString and valueOf enumeration bugs in IE < 9
        for (const key in obj) {
            if (Object.prototype.hasOwnProperty.call(obj, key)) {
                return false;
            }
        }

        return true;
    }
}

@NgModule({
    imports: [CommonModule, GlxSharedModule, TooltipModule],
    exports: [UserViewer],
    declarations: [UserViewer]
})

export class UserViewerModule {
}
